@@ -10,15 +10,15 @@ from keyrings.alt import file
 
 def is_crypto_supported():
     try:
-        __import__('Crypto.Cipher.AES')
-        __import__('Crypto.Protocol.KDF')
-        __import__('Crypto.Random')
+        __import__('Cryptodome.Cipher.AES')
+        __import__('Cryptodome.Protocol.KDF')
+        __import__('Cryptodome.Random')
     except ImportError:
         return False
     return True
 
 
-@pytest.mark.skipif(not is_crypto_supported(), reason="Need Crypto module")
+@pytest.mark.skipif(not is_crypto_supported(), reason="Need pycryptodomex module")
 class TestCryptedFileKeyring(FileKeyringTests):
     @pytest.fixture(autouse=True)
     def mocked_getpass(self, monkeypatch):
